.. :changelog:

History
-------

1.1 (2019-07-01)
+++++++++++++++++

* Added validation on types before saving (Thanks to @aaloy!)

1.0 (2018-10-2)
+++++++++++++++++

* Added model for user's custom options.

1.0a3 (2018-8-29)
+++++++++++++++++

* Fixed dependency with GeoDejango.

1.0a2 (2017-2-20)
+++++++++++++++++

* Add search options to admin.
* Export current options command.

1.0a1 (2017-2-20)
+++++++++++++++++

* First release on PyPI.
